@@ -8,11 +8,12 @@ from argparse import ArgumentDefaultsHelpFormatter, ArgumentParser, Namespace
 from datetime import datetime
 from importlib.resources import files
 from pathlib import Path
+from urllib.parse import ParseResult, urlparse
 
 from .excel_definition import ExcelDefinition
 from .excel_operation import output_to_excel_file, process_excel_file
 
-__all__ = ["sort_excel_file", "generate_template", "update_jira_access_token"]
+__all__ = ["sort_excel_file", "generate_template", "update_jira_info"]
 
 
 def get_args_for_sort_excel_file() -> Namespace:
@@ -37,14 +38,21 @@ def get_args_for_sort_excel_file() -> Namespace:
         metavar="",
         type=pathlib.Path,
         required=False,
-        help="Excel definition JSON file.",
+        help="Excel definition file. File format: JSON.",
     )
     parser.add_argument(
         "--sprint_schedule_file",
         metavar="",
         type=pathlib.Path,
         required=False,
-        help="Milestone priority JSON file.",
+        help="Milestone priority file. File format: JSON.",
+    )
+    parser.add_argument(
+        "--jira_configuration_file",
+        metavar="",
+        type=pathlib.Path,
+        required=False,
+        help="JIRA configuration file including status information and something else. File format: JSON.",
     )
     parser.add_argument(
         "--over_write",
@@ -119,7 +127,7 @@ def sort_excel_file() -> None:
 
         if args.excel_definition_file is not None:
             excel_definition_file_absolute_path = pathlib.Path(
-                args.excel_definition_file
+                pathlib.Path.cwd() / args.excel_definition_file.as_posix()
             ).resolve()
 
             if excel_definition_file_absolute_path.suffix.lower() != ".json":
@@ -132,7 +140,7 @@ def sort_excel_file() -> None:
 
         if args.sprint_schedule_file is not None:
             sprint_schedule_file_absolute_path = pathlib.Path(
-                args.sprint_schedule_file
+                pathlib.Path.cwd() / args.sprint_schedule_file.as_posix()
             ).resolve()
 
             if sprint_schedule_file_absolute_path.suffix.lower() != ".json":
@@ -141,6 +149,19 @@ def sort_excel_file() -> None:
                 )
                 quit(1)
 
+        jira_configuration_file_absolute_path = None
+
+        if args.jira_configuration_file is not None:
+            jira_configuration_file_absolute_path = pathlib.Path(
+                pathlib.Path.cwd() / args.sprint_schedule_file.as_posix()
+            ).resolve()
+
+            if jira_configuration_file_absolute_path.suffix.lower() != ".json":
+                print(
+                    f"Please provide an JSON file for sprint schedule. File: {jira_configuration_file_absolute_path}."
+                )
+                quit(1)
+
         # Over write parameter.
         over_write = True
         if args.over_write is not None:
@@ -151,6 +172,7 @@ def sort_excel_file() -> None:
             output_file_absolute_path,
             excel_definition_file_absolute_path,
             sprint_schedule_file_absolute_path,
+            jira_configuration_file_absolute_path,
             over_write,
         )
 
@@ -170,8 +192,8 @@ def get_args_for_generate_template() -> Namespace:
         "template_type",
         metavar="template_type",
         type=str,
-        help="What kind of file template you want to generate. Choices: excel, excel-definition, sprint-schedule or jira-status-mapping.",
-        choices=["excel", "excel-definition", "sprint-schedule", "jira-status-mapping"],
+        help="What kind of file template you want to generate. Choices: excel, excel-definition, sprint-schedule or jira-configuration.",
+        choices=["excel", "excel-definition", "sprint-schedule", "jira-configuration"],
     )
 
     return parser.parse_args()
@@ -202,12 +224,12 @@ def generate_template():
         elif template_type == "sprint-schedule":
             result = copyfile(
                 SRC_ASSETS / "sprint_schedule.json",
-                _generate_timestamp_filename("sprint_schedule-template", ".json"),
+                _generate_timestamp_filename("sprint-schedule-template", ".json"),
             )
         else:
             result = copyfile(
-                SRC_ASSETS / "jira_status_mapping.json",
-                _generate_timestamp_filename("jira_status_mapping-template", ".json"),
+                SRC_ASSETS / "jira_configuration.json",
+                _generate_timestamp_filename("jira-configuration-template", ".json"),
             )
 
         if result is not None and result.is_file():
@@ -240,53 +262,84 @@ def _generate_excel_template(output_file: "Path") -> "Path | None":
         return None
 
 
-def get_args_for_update_jira_access_token() -> Namespace:
+def get_args_for_update_jira_info() -> Namespace:
     parser = ArgumentParser(
-        description="Jira tool: Used to add/update jira access token",
+        description="Jira tool: Used to add/update jira url or access token.",
         formatter_class=ArgumentDefaultsHelpFormatter,
     )
 
     parser.add_argument(
-        "access_token",
-        metavar="access_token",
+        "--access_token",
+        metavar="",
         type=str,
-        help="Please follow the documentation to get your own access token",
+        required=False,
+        help="Please follow the documentation to get your own access token.",
+    )
+
+    parser.add_argument(
+        "--url",
+        metavar="",
+        type=str,
+        required=False,
+        help="Please provide the JIRA website url.",
     )
 
     return parser.parse_args()
 
 
-def update_jira_access_token():
+def update_jira_info():
     try:
-        args = get_args_for_update_jira_access_token()
+        args = get_args_for_update_jira_info()
 
-        access_token: str = str(args.access_token)
-
-        if len(access_token) == 0 or access_token.isspace():
-            print("Please provide invalid access token.")
-            quit(1)
-
-        from dotenv import load_dotenv, set_key
+        from dotenv import set_key
 
         env_file: Path = SRC_ASSETS / ".env"
 
         if not env_file.exists():
             env_file.touch()
 
-        result, _, _ = set_key(
-            env_file,
-            key_to_set="JIRA_ACCESS_TOKEN",
-            value_to_set=access_token,
-            quote_mode="never",
-        )
+        # URL Part
+        if args.url is not None:
+            parsed_url: ParseResult = urlparse(str(args.url))
 
-        if result is True:
-            print("Add/Update access token success!")
-            quit(0)
-        else:
-            print("Add/Update access token failed!")
+            if parsed_url.scheme != "https" and parsed_url.scheme != "http":
+                print("Please check the jira url.")
+            else:
+                result, _, _ = set_key(
+                    env_file,
+                    key_to_set="JIRA_URL",
+                    value_to_set=f"{parsed_url.scheme}://{parsed_url.netloc}",
+                    quote_mode="never",
+                )
 
-        quit(1)
+                if result is True:
+                    print("Add/Update jira url success!")
+                    quit(0)
+                else:
+                    print("Add/Update jira url failed!")
+                    quit(1)
+
+        # ACCESS TOKEN Part
+        if args.access_token is not None:
+            access_token: str = str(args.access_token)
+
+            if len(access_token.strip()) == 0 or access_token.isspace():
+                print("Please check the access token.")
+                quit(1)
+            else:
+                result, _, _ = set_key(
+                    env_file,
+                    key_to_set="JIRA_ACCESS_TOKEN",
+                    value_to_set=access_token,
+                    quote_mode="never",
+                )
+
+                if result is True:
+                    print("Add/Update access token success!")
+                    quit(0)
+                else:
+                    print("Add/Update access token failed!")
+                    quit(1)
     except Exception as e:
         print(e)
         quit(1)
