@@ -67,6 +67,7 @@ class ExcelDefinitionColumn(TypedDict):
     inline_weights: int
     raise_ranking: int
     scope_raise_ranking: int
+    jira_field_mapping: dict[str, str] | NoneType
 
 
 def parse_json_item_to_excel_definition_column(json_item: Any) -> ExcelDefinitionColumn:
@@ -80,6 +81,7 @@ def parse_json_item_to_excel_definition_column(json_item: Any) -> ExcelDefinitio
     column_inline_weights = -1
     column_raise_ranking = -1
     column_scope_raise_ranking = -1
+    column_jira_field_mapping = None
 
     for key, value in json_item.items():
         if key.lower() == "index".lower():
@@ -102,6 +104,8 @@ def parse_json_item_to_excel_definition_column(json_item: Any) -> ExcelDefinitio
             column_raise_ranking = value
         if key.lower() == "ScopeRaiseRanking".lower():
             column_scope_raise_ranking = value
+        if key.lower() == "JiraFieldMapping".lower():
+            column_jira_field_mapping = value
 
     return ExcelDefinitionColumn(
         index=column_index,
@@ -114,6 +118,7 @@ def parse_json_item_to_excel_definition_column(json_item: Any) -> ExcelDefinitio
         inline_weights=column_inline_weights,
         raise_ranking=column_raise_ranking,
         scope_raise_ranking=column_scope_raise_ranking,
+        jira_field_mapping=column_jira_field_mapping,
     )
 
 
@@ -131,7 +136,7 @@ class ExcelDefinition:
         """
 
         if content is None:
-            raise ValueError("The content is invalid")
+            raise ValueError("There is no content in the excel definition file.")
 
         try:
             raw_data = json.loads(content)
@@ -143,7 +148,7 @@ class ExcelDefinition:
                 self.columns.append(parse_json_item_to_excel_definition_column(item))
         except Exception:
             raise ValueError(
-                "The JSON file structure is invalid. Please check the documentation: https://github.com/SharryXu/jira-tool"
+                "The JSON structure of the excel definition file is wrong. Please check the documentation: https://github.com/SharryXu/jira-tool"
             )
 
         return self
@@ -246,6 +251,7 @@ class ExcelDefinition:
             column_inline_weights: int = column["inline_weights"]
             column_raise_ranking: int = column["raise_ranking"]
             column_scope_raise_ranking: int = column["scope_raise_ranking"]
+            column_jira_field_mapping: dict | None = column["jira_field_mapping"]
 
             # Check Name cannot be empty
             if type(column_name) is not str or len(column_name) == 0:
@@ -338,6 +344,27 @@ class ExcelDefinition:
                         f"Column do not support Scope Raise Ranking feature. Column: {column_name}"
                     )
 
+            if column_jira_field_mapping is None:
+                continue
+            elif (
+                column_jira_field_mapping is not None
+                and type(column_jira_field_mapping) is not dict
+            ):
+                invalid_definitions.append(
+                    f"Jira Field Mapping can only be dictionary. Column: {column_name}"
+                )
+            else:
+                jira_field_name = column_jira_field_mapping.get("name", None)
+                if jira_field_name is None or jira_field_name.isspace():
+                    invalid_definitions.append(
+                        f"Jira Field Mapping has the invalid name. Column: {column_name}"
+                    )
+                jira_field_path = column_jira_field_mapping.get("path", None)
+                if jira_field_path is None or jira_field_path.isspace():
+                    invalid_definitions.append(
+                        f"Jira Field Mapping has the invalid path. Column: {column_name}"
+                    )
+
         if len(invalid_definitions) == 0:
             self.columns.sort(key=lambda c: c["index"], reverse=False)
 
