@@ -9,11 +9,14 @@ from importlib.resources import files
 from pathlib import Path
 
 import openpyxl
+from openpyxl.workbook import Workbook
+from openpyxl.worksheet._read_only import ReadOnlyWorksheet
+from openpyxl.worksheet.worksheet import Worksheet
 from urllib3 import disable_warnings
 
 from .excel_definition import *
 from .jira_client import *
-from .jira_status import *
+from .jira_configuration import *
 from .milestone import *
 from .priority import *
 from .sprint_schedule import *
@@ -62,10 +65,16 @@ def read_excel_file(
     if not pathlib.Path(file).exists():
         raise ValueError(f"The input excel file: {file} cannot be found.")
 
-    wb = openpyxl.load_workbook(
+    wb: Workbook = openpyxl.load_workbook(
         str(file), read_only=True, keep_vba=False, data_only=True, keep_links=True
     )
-    sheet = wb.active
+
+    if wb.active is None or (
+        type(wb.active) is not Worksheet and type(wb.active) is not ReadOnlyWorksheet
+    ):
+        raise ValueError("The input excel file doesn't contain any sheets.")
+
+    sheet: Worksheet = wb.active
 
     # The count of column is taking from the definition file to avoid too many columns inside the excel file.
     # Also, need to avoid exceed the range of the actual count.
@@ -184,7 +193,11 @@ def output_to_excel_file(
             raise ValueError(f"The output excel file: {file} is already exist.")
 
     wb = openpyxl.Workbook()
-    sheet = wb.active
+
+    if wb.active is None or type(wb.active) is not Worksheet:
+        raise ValueError("The output file doesn't contain any active sheets.")
+
+    sheet: Worksheet = wb.active
 
     # TODO: Refactor this method to return needed properties list.
     excel_definition_columns = excel_definition.get_columns()
@@ -218,8 +231,9 @@ def output_to_excel_file(
 def process_excel_file(
     input_file: "str | Path",
     output_file: "str | Path",
-    excel_definition_config: "str | Path | None" = None,
-    sprint_schedule_config: "str | Path | None" = None,
+    excel_definition_file: "str | Path | None" = None,
+    sprint_schedule_file: "str | Path | None" = None,
+    jira_configuration_file: "str | Path | None" = None,
     over_write: bool = True,
 ):
     """
@@ -231,39 +245,39 @@ def process_excel_file(
     :parm output_file:
         The sorted excel file location. (Absolute path only)
 
-    :parm sprint_schedule_config:
+    :parm sprint_schedule_file:
         The JSON file which contains the priority list to calculate the :py:class:`Milestone`
 
-    :parm excel_definition_config:
+    :parm excel_definition_file:
         The JSON file which contains the input excel file's structure.
 
     :parm over_write:
         Whether or not the exist output file will be over-write.
     """
     sprint_schedule = SprintScheduleStore()
-    if sprint_schedule_config is None:
+    if sprint_schedule_file is None:
         sprint_schedule.load(
             files("jira_tool.assets").joinpath("sprint_schedule.json").read_text()
         )
         print("Using default sprint schedule...")
     else:
-        sprint_schedule.load_file(sprint_schedule_config)
+        sprint_schedule.load_file(sprint_schedule_file)
         print("Using custom sprint schedule...")
 
     excel_definition = ExcelDefinition()
-    if excel_definition_config is None:
+    if excel_definition_file is None:
         excel_definition.load(
             files("jira_tool.assets").joinpath("excel_definition.json").read_text()
         )
         print("Using default excel definition...")
     else:
-        excel_definition.load_file(excel_definition_config)
+        excel_definition.load_file(excel_definition_file)
         print("Using custom excel definition...")
 
     validation_result = excel_definition.validate()
     if len(validation_result) != 0:
         print(
-            "Validating excel definition failed. Please check below information to fix."
+            "Validating excel definition failed. Please check below information to fix first."
         )
         for item in validation_result:
             print(item)
@@ -284,6 +298,18 @@ def process_excel_file(
 
     load_dotenv(ASSETS / ".env")
 
+    jira_url: str | None = os.environ.get("JIRA_URL", default=None)
+    if (
+        # TODO: Avoid duplicate logic.
+        jira_url is None
+        or jira_url.isspace()
+        or len(jira_url) == 0
+    ):
+        print(
+            "The jira url is invalid. Please use the update-jira-info command to add/update url."
+        )
+        return
+
     jira_acccess_token: str | None = os.environ.get("JIRA_ACCESS_TOKEN", default=None)
     if (
         # TODO: Avoid duplicate logic.
@@ -292,28 +318,47 @@ def process_excel_file(
         or len(jira_acccess_token) == 0
     ):
         print(
-            "The jira access token is invalid. Please use the update-jira-access-token command to add/update token."
+            "The jira access token is invalid. Please use the update-jira-info command to add/update token."
         )
         return
 
-    jira_client = JiraClient(jira_acccess_token)
+    jira_client = JiraClient(jira_url, jira_acccess_token)
 
     if not jira_client.health_check():
         print(
-            "The jira access token is revoked. Please use the update-jira-access-token command to add/update token."
+            "The jira access token is revoked. Please use the update-jira-info command to add/update token."
         )
         return
 
-    noneed_sort_statuses = get_no_need_sort_statuses()
+    noneed_sort_statuses = get_no_need_sort_statuses(jira_configuration_file)
 
     stories_has_story_id = []
     for story in stories:
         if story["storyId"] is not None:
             stories_has_story_id.append(story["storyId"].strip())
 
-    jira_query_result = jira_client.get_stories_status(stories_has_story_id)
+    jira_fields = []
 
-    print("Quering all stories' status...")
+    for definition_column in excel_definition.get_columns():
+        if (
+            definition_column["name"] is None
+            or definition_column["jira_field_mapping"] is None
+        ):
+            continue
+        else:
+            jira_fields.append(
+                {
+                    "name": definition_column["name"],
+                    "jira_name": definition_column["jira_field_mapping"]["name"],
+                    "jira_path": definition_column["jira_field_mapping"]["path"],
+                }
+            )
+
+    jira_query_result = jira_client.get_stories_detail(
+        stories_has_story_id, jira_fields
+    )
+
+    print("Quering all stories' jira properties...")
 
     stories_need_sort = []
     stories_no_need_sort = []
@@ -324,21 +369,28 @@ def process_excel_file(
             continue
         story_id: str = story["storyId"].lower().strip()
         if story_id in jira_query_result:
-            story["status"] = jira_query_result[story_id]
+            for jira_field in jira_fields:
+                story[jira_field["name"]] = jira_query_result[story_id][
+                    jira_field["jira_name"]
+                ]
         else:
             # Story ID has been changed because of convertion.
-            temp_result = jira_client.get_stories_status([story_id])
+            temp_result = jira_client.get_stories_detail([story_id], jira_fields)
             if len(temp_result) > 0:
-                story["storyId"] = list(temp_result.keys())[0]
-                story["status"] = list(temp_result.values())[0]
+                story["storyId"] = list(temp_result.keys())[0].upper()
+                for jira_field in jira_fields:
+                    story[jira_field["name"]] = list(temp_result.values())[0][
+                        jira_field["jira_name"]
+                    ].upper()
                 print(
-                    f"Story id has been changed. Previous: {story_id}, Current: {story['storyId']}"
+                    f"Story id has been changed. Previous: {story_id.upper()}, Current: {story['storyId'].upper()}"
                 )
             else:
-                print(f"Cannot find status information for story: {story_id}")
+                print(f"Cannot find related information for story: {story_id}")
                 stories_no_need_sort.append(story)
                 continue
 
+        # TODO: Add filter strategy to the program.
         if story["status"].upper() in noneed_sort_statuses:
             story.need_sort = False
             stories_no_need_sort.append(story)
