@@ -310,82 +310,6 @@ def _internal_sort_stories_by_property_and_order(
         stories.sort(key=attrgetter(column_name), reverse=sort_order)
 
 
-def sort_stories_by_raise_ranking(
-    stories: "list[Story]", excel_definition: ExcelDefinition, config: dict
-) -> "list[Story]":
-    if stories is None:
-        return []
-    sort_rules: list[tuple[str, int, int]] = []
-    excel_definition_columns = excel_definition.get_columns()
-
-    for column in excel_definition_columns:
-        if column["raise_ranking"] > 0 and column["name"] is not None:
-            sort_rules.append(
-                (
-                    column["name"],
-                    column["raise_ranking"],
-                    column["scope_raise_ranking"],
-                )
-            )
-
-    if len(sort_rules) == 0:
-        return stories
-
-    result = []
-
-    # New raise ranking mode.
-    if "ParentScopeIndexRange" in config:
-        sort_rules.sort(key=lambda x: x[2], reverse=True)  # sort by scope_raise_ranking
-
-        column_definitions: dict[int, ExcelDefinitionColumn] = {
-            c["index"]: c for c in excel_definition_columns
-        }
-
-        result = _internal_raise_story_ranking_by_property_considering_parent_level(
-            stories,
-            column_definitions,
-            sort_rules,
-            config["ParentScopeIndexRange"],
-        )
-    else:
-        sort_rules.sort(key=lambda x: x[1], reverse=True)  # sort by raise_ranking
-
-        for property_name, _, _ in sort_rules:
-            result = _internal_raise_story_ranking_by_property(stories, property_name)
-
-    return result
-
-
-def _internal_raise_story_ranking_by_property(
-    stories: "list[Story]", property_name: str
-) -> "list[Story]":
-    if stories is None or len(stories) == 0:
-        return stories
-    # Use first story as example
-    if not hasattr(stories[0], property_name):
-        return stories
-    return _raise_story_ranking_by_property(stories, property_name)
-
-
-# Only bool indicator for now
-def _raise_story_ranking_by_property(
-    stories: "list[Story]", property_name: str
-) -> "list[Story]":
-    if type(getattr(stories[0], property_name)) is not bool:
-        return stories
-    result: list[Story] = [stories[0]] * len(stories)
-    j = 0
-    for i in range(len(stories)):
-        if getattr(stories[i], property_name) is True:
-            result[j] = stories[i]
-            j += 1
-    for i in range(len(stories)):
-        if getattr(stories[i], property_name) is False:
-            result[j] = stories[i]
-            j += 1
-    return result
-
-
 def _internal_sort_stories_by_property_and_order_considering_parent_range(
     stories: "list[Story]",
     story_columns: "dict[int, ExcelDefinitionColumn]",
@@ -424,10 +348,78 @@ def _internal_sort_stories_by_property_and_order_considering_parent_range(
     return stories
 
 
+def sort_stories_by_raise_ranking(
+    stories: "list[Story]", excel_definition: ExcelDefinition, config: dict
+) -> "list[Story]":
+    if stories is None:
+        return []
+    sort_rules: list[tuple[str, int]] = []
+    excel_definition_columns = excel_definition.get_columns()
+
+    result = []
+
+    # New raise ranking mode.
+    if "ParentScopeIndexRange" in config:
+        for column in excel_definition_columns:
+            if column["scope_raise_ranking"] > 0 and column["name"] is not None:
+                sort_rules.append(
+                    (
+                        column["name"],
+                        column["scope_raise_ranking"],
+                    )
+                )
+
+        if len(sort_rules) == 0:
+            return stories
+
+        sort_rules.sort(key=lambda x: x[1], reverse=True)  # sort by scope_raise_ranking
+
+        column_definitions: dict[int, ExcelDefinitionColumn] = {
+            c["index"]: c for c in excel_definition_columns
+        }
+
+        result = _internal_raise_story_ranking_by_property_considering_parent_level(
+            stories,
+            column_definitions,
+            sort_rules,
+            config["ParentScopeIndexRange"],
+        )
+    else:
+        for column in excel_definition_columns:
+            if column["raise_ranking"] > 0 and column["name"] is not None:
+                sort_rules.append(
+                    (
+                        column["name"],
+                        column["raise_ranking"],
+                    )
+                )
+
+        if len(sort_rules) == 0:
+            return stories
+
+        sort_rules.sort(key=lambda x: x[1], reverse=True)  # sort by raise_ranking
+
+        for property_name, _ in sort_rules:
+            result = _internal_raise_story_ranking_by_property(stories, property_name)
+
+    return result
+
+
+def _internal_raise_story_ranking_by_property(
+    stories: "list[Story]", property_name: str
+) -> "list[Story]":
+    if stories is None or len(stories) == 0:
+        return stories
+    # Use first story as example
+    if not hasattr(stories[0], property_name):
+        return stories
+    return _raise_story_ranking_by_property(stories, property_name)
+
+
 def _internal_raise_story_ranking_by_property_considering_parent_level(
     stories: "list[Story]",
     story_columns: "dict[int, ExcelDefinitionColumn]",
-    sort_rules: "list[tuple[str, int, int]]",
+    sort_rules: "list[tuple[str, int]]",
     parent_level_index_range: "set[int]",
 ) -> "list[Story]":
     begin_index = 0
@@ -449,7 +441,7 @@ def _internal_raise_story_ranking_by_property_considering_parent_level(
                 break
 
         # Same parent level process
-        for column_name, _, _ in reversed(sort_rules):
+        for column_name, _ in reversed(sort_rules):
             stories[begin_index : end_index + 1] = _raise_story_ranking_by_property(
                 stories[begin_index : end_index + 1], column_name
             )
@@ -458,3 +450,22 @@ def _internal_raise_story_ranking_by_property_considering_parent_level(
         end_index = begin_index
 
     return stories
+
+
+# Only bool indicator for now
+def _raise_story_ranking_by_property(
+    stories: "list[Story]", property_name: str
+) -> "list[Story]":
+    if type(getattr(stories[0], property_name)) is not bool:
+        return stories
+    result: list[Story] = [stories[0]] * len(stories)
+    j = 0
+    for i in range(len(stories)):
+        if getattr(stories[i], property_name) is True:
+            result[j] = stories[i]
+            j += 1
+    for i in range(len(stories)):
+        if getattr(stories[i], property_name) is False:
+            result[j] = stories[i]
+            j += 1
+    return result
